==> payara-embedded-all-4.1.1.171.1-sources.jar: org/glassfish/api/admin/ParameterMap.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.api.admin;

import org.jvnet.hk2.component.MultiMap;

/**
 * A map from parameter name to a list of parameter values.
 * (Really just a more convenient name for MultiMap.)
 */
public class ParameterMap extends MultiMap<String, String> {
    /**
     * Creates an empty ParameterMap.
     */
    public ParameterMap() {
        super();
    }

    /**
     * Copy constructor.
     */
    public ParameterMap(ParameterMap base) {
        super(base);
    }

    /**
     * Fluent API for adding parameters to the map.
     * @param k
     * @param v
     * @return ParameterMap
     */
    public ParameterMap insert(String k, String v) {
        add(k, v);
        return this;
    }
}

==> payara-embedded-all-6.2023.2-sources.jar: org/glassfish/api/admin/ParameterMap.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

// Portions Copyright [2020] Payara Foundation and/or affiliates
package org.glassfish.api.admin;

import java.util.Objects;
import java.util.function.Supplier;

import org.jvnet.hk2.component.MultiMap;

/**
 * A map from parameter name to a list of parameter values.
 * (Really just a more convenient name for MultiMap.)
 */
public class ParameterMap extends MultiMap<String, String> {

    private static final long serialVersionUID = -4283882776966412741L;

    /**
     * Creates an empty ParameterMap.
     */
    public ParameterMap() {
        super();
    }


    /**
     * Copy constructor - copies all entries from base.
     *
     * @param base source of entries
     */
    public ParameterMap(ParameterMap base) {
        super(base);
    }


    /**
     * Fluent API for adding parameters to the map.
     *
     * @param key
     * @param value
     * @return ParameterMap
     */
    public ParameterMap insert(String key, String value) {
        add(key, value);
        return this;
    }

    /**
     * Fluent API for adding parameters to the map.
     *
     * @param key
     * @param value - used if not null
     * @param defaultValue - used if the value is null
     * @return ParameterMap
     */
    public ParameterMap insert(String key, String value, String defaultValue) {
        return insert(key, value == null ? defaultValue : value);
    }


    /**
     * Fluent API for adding parameters to the map.
     *
     * @param key
     * @param value - used if not null
     * @param defaultValueSupplier - used if the value is null, must not be null.
     * @return ParameterMap
     */
    public ParameterMap insert(String key, String value, Supplier<String> defaultValueSupplier) {
        Objects.requireNonNull(defaultValueSupplier, "defaultValueSupplier must not be null!");
        return insert(key, value == null ? defaultValueSupplier.get() : value);
    }
}
